@@ -3,6 +3,7 @@ from __future__ import annotations
 from typing import Callable, ClassVar, Optional, Sequence
 
 from textual.app import RenderResult
+from textual.color import Color
 from textual.reactive import reactive
 from textual.renderables.sparkline import Sparkline as SparklineRenderable
 from textual.widget import Widget
@@ -56,6 +57,8 @@ class Sparkline(Widget):
         self,
         data: Sequence[float] | None = None,
         *,
+        min_color: Color | str | None = None,
+        max_color: Color | str | None = None,
         summary_function: Callable[[Sequence[float]], float] | None = None,
         name: str | None = None,
         id: str | None = None,
@@ -66,6 +69,8 @@ class Sparkline(Widget):
 
         Args:
             data: The initial data to populate the sparkline with.
+            min_color: The color of the minimum value, or `None` to take from CSS.
+            max_color: the color of the maximum value, or `None` to take from CSS.
             summary_function: Summarizes bar values into a single value used to
                 represent each bar.
             name: The name of the widget.
@@ -74,6 +79,8 @@ class Sparkline(Widget):
             disabled: Whether the widget is disabled or not.
         """
         super().__init__(name=name, id=id, classes=classes, disabled=disabled)
+        self.min_color = None if min_color is None else Color.parse(min_color)
+        self.max_color = None if max_color is None else Color.parse(max_color)
         self.data = data
         if summary_function is not None:
             self.summary_function = summary_function
@@ -83,14 +90,20 @@ class Sparkline(Widget):
         if not self.data:
             return "<empty sparkline>"
         _, base = self.background_colors
+        min_color = base + (
+            self.get_component_styles("sparkline--min-color").color
+            if self.min_color is None
+            else self.min_color
+        )
+        max_color = base + (
+            self.get_component_styles("sparkline--max-color").color
+            if self.max_color is None
+            else self.max_color
+        )
         return SparklineRenderable(
             self.data,
             width=self.size.width,
-            min_color=(
-                base + self.get_component_styles("sparkline--min-color").color
-            ).rich_color,
-            max_color=(
-                base + self.get_component_styles("sparkline--max-color").color
-            ).rich_color,
+            min_color=min_color.rich_color,
+            max_color=max_color.rich_color,
             summary_function=self.summary_function,
         )
